@@ -18,6 +18,7 @@
 import argparse
 import concurrent.futures
 import configparser
+import sys
 from logging import INFO
 from os import path
 from time import strftime
@@ -28,13 +29,15 @@ import flwr_experimental.baseline.tf_fashion_mnist.settings as tf_fashion_mnist_
 import flwr_experimental.baseline.tf_hotkey.settings as tf_hotkey_settings
 from flwr.common.logger import configure, log
 from flwr_experimental.baseline import command
-from flwr_experimental.ops.cluster import Cluster, Instance
+from flwr_experimental.baseline.setting import Baseline
+from flwr_experimental.ops.cluster import Cluster
 from flwr_experimental.ops.compute.adapter import Adapter
 from flwr_experimental.ops.compute.docker_adapter import DockerAdapter
 from flwr_experimental.ops.compute.ec2_adapter import EC2Adapter
+from flwr_experimental.ops.instance import Instance
 
 OPS_INI_PATH = path.normpath(
-    f"{path.dirname(path.realpath(__file__))}/../../../.flower_ops"
+    f"{path.dirname(path.realpath(__file__))}/../../../../.flower_ops"
 )
 
 # Read config file and extract all values which are needed further down.
@@ -44,7 +47,9 @@ CONFIG.read(OPS_INI_PATH)
 WHEEL_FILENAME = CONFIG.get("paths", "wheel_filename")
 WHEEL_LOCAL_PATH = path.expanduser(CONFIG.get("paths", "wheel_dir")) + WHEEL_FILENAME
 
-DOCKER_PRIVATE_KEY = path.realpath(path.dirname(__file__) + "/../../../docker/ssh_key")
+DOCKER_PRIVATE_KEY = path.realpath(
+    path.dirname(__file__) + "/../../../../docker/ssh_key"
+)
 
 
 def now() -> str:
@@ -90,6 +95,18 @@ def configure_cluster(
     return cluster
 
 
+def load_baseline_setting(baseline: str, setting: str) -> Baseline:
+    """Return appropriate baseline setting."""
+    if baseline == "tf_cifar":
+        return tf_cifar_settings.get_setting(setting)
+    if baseline == "tf_fashion_mnist":
+        return tf_fashion_mnist_settings.get_setting(setting)
+    if baseline == "tf_hotkey":
+        return tf_hotkey_settings.get_setting(setting)
+
+    raise Exception("Setting not found.")
+
+
 # pylint: disable=too-many-arguments, too-many-locals
 def run(baseline: str, setting: str, adapter: str) -> None:
     """Run baseline."""
@@ -101,14 +118,7 @@ def run(baseline: str, setting: str, adapter: str) -> None:
         else f"/home/ubuntu/{WHEEL_FILENAME}"
     )
 
-    if baseline == "tf_cifar":
-        settings = tf_cifar_settings.get_setting(setting)
-    elif baseline == "tf_fashion_mnist":
-        settings = tf_fashion_mnist_settings.get_setting(setting)
-    elif baseline == "tf_hotkey":
-        settings = tf_hotkey_settings.get_setting(setting)
-    else:
-        raise Exception("Setting not found.")
+    settings = load_baseline_setting(baseline, setting)
 
     # Get instances and add a logserver to the list
     instances = settings.instances
@@ -131,6 +141,10 @@ def run(baseline: str, setting: str, adapter: str) -> None:
     # Install the wheel on all instances
     log(INFO, "(4/9) Install wheel on all instances.")
     cluster.exec_all(command.install_wheel(wheel_remote_path))
+    extras = ["examples-tensorflow"] if "tf_" in baseline else ["examples-pytorch"]
+    cluster.exec_all(
+        command.install_wheel(wheel_remote_path=wheel_remote_path, wheel_extras=extras)
+    )
 
     # Download datasets in server and clients
     log(INFO, "(5/9) Download dataset on server and clients.")
@@ -154,7 +168,9 @@ def run(baseline: str, setting: str, adapter: str) -> None:
     cluster.exec(
         "server",
         command.start_server(
-            log_host=f"{logserver.private_ip}:8081", baseline=baseline, setting=setting,
+            log_host=f"{logserver.private_ip}:8081",
+            baseline=baseline,
+            setting=setting,
         ),
     )
 
@@ -184,7 +200,7 @@ def run(baseline: str, setting: str, adapter: str) -> None:
     # Shutdown server and client instance after 10min if not at least one Flower
     # process is running it
     log(INFO, "(9/9) Start shutdown watcher script.")
-    cluster.exec_all(command.watch_and_shutdown("flower", adapter))
+    cluster.exec_all(command.watch_and_shutdown("flwr", adapter))
 
     # Give user info how to tail logfile
     private_key = (
@@ -203,24 +219,36 @@ def run(baseline: str, setting: str, adapter: str) -> None:
 def main() -> None:
     """Start Flower baseline."""
     parser = argparse.ArgumentParser(description="Flower")
+
+    # When adding a new setting make sure to modify the load_baseline_setting function
+    possible_baselines = ["tf_cifar", "tf_fashion_mnist", "tf_hotkey"]
+    possible_settings = []
+    all_settings = [
+        list(tf_cifar_settings.SETTINGS.keys()),
+        list(tf_fashion_mnist_settings.SETTINGS.keys()),
+        list(tf_hotkey_settings.SETTINGS.keys()),
+    ]
+
+    # Show only relevant settings based on baseline as choices
+    # for --setting parameter
+    baseline_arg = [arg for arg in sys.argv if "--baseline" in arg]
+    if len(baseline_arg) > 0:
+        selected_baseline = baseline_arg[0].split("=")[1]
+        idx = possible_baselines.index(selected_baseline)
+        possible_settings = all_settings[idx]
+
     parser.add_argument(
         "--baseline",
         type=str,
         required=True,
-        choices=["tf_cifar", "tf_fashion_mnist", "tf_hotkey"],
+        choices=possible_baselines,
         help="Name of baseline name to run.",
     )
     parser.add_argument(
         "--setting",
         type=str,
         required=True,
-        choices=list(
-            set(
-                list(tf_cifar_settings.SETTINGS.keys())
-                + list(tf_fashion_mnist_settings.SETTINGS.keys())
-                + list(tf_hotkey_settings.SETTINGS.keys())
-            )
-        ),
+        choices=possible_settings,
         help="Name of setting to run.",
     )
     parser.add_argument(
