@@ -17,13 +17,13 @@
 
 from typing import List
 
-from flwr_experimental.baseline.common import (
+from flwr_experimental.baseline.config import (
     configure_client_instances,
     sample_delay_factors,
     sample_real_delay_factors,
 )
 from flwr_experimental.baseline.setting import Baseline, ClientSetting, ServerSetting
-from flwr_experimental.ops.cluster import Instance
+from flwr_experimental.ops.instance import Instance
 
 ROUNDS = 50
 MIN_NUM_CLIENTS = 45
@@ -71,7 +71,10 @@ def get_instance_name(
 
 
 def configure_uniform_clients(
-    iid_fraction: float, instance_names: List[str], num_clients: int, dry_run: bool,
+    iid_fraction: float,
+    instance_names: List[str],
+    num_clients: int,
+    dry_run: bool,
 ) -> List[ClientSetting]:
     """Configure `num_clients`, all using the same delay factor."""
     clients = []
